greenheart.simulation.technologies.offshore.fixed\_platform
===========================================================

.. automodule:: greenheart.simulation.technologies.offshore.fixed_platform

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      calc_substructure_mass_and_cost
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      FixedPlatformDesign
      FixedPlatformInstallation
   
   

   
   
   



